#!/bin/bash

# NOTE clustalw2_sleep has been replaced by clustalw2
# in order to increase the speed of this script


##############
# Exercise 1 #
##############

# this command shows us where we are in the directory tree
pwd

# we create a directory
mkdir pract_so/

# and another inside the previously created one
mkdir pract_so/WORK

# we enter in this directory
cd pract_so/

# we check were we are again
pwd

# we copy a directory and all its contents to our present working directory
cp -r /home/$USER/OSCAR_OS/SEQS/ .

# we list the contents of the directory
ls

# we enter in the WORK directory
cd WORK

# check, if you want, were you are

# we link a program to here, if we want to keep the name only the source file is needed as an argument
ln -s /home/$USER/OSCAR_OS/clustalw2_sleep

# we link a file using an absolute path creating it with a different name
ln -s /home/$USER/pract_so/SEQS/LexA_all.fst LexA_all.fst_1

# we link a file using a relative path creating it with a different name
ln -s ../SEQS/LexA_all.fst LexA_all.fst_2

# we list the contents of the directory in a long format where we can see were the links point to
ls -l

# we go to the parent directory
cd ..

# we go to the parent directory so now we are in our home (you don't believe me? check it!)
cd ..

# we change the name of the directory where we've been working
mv pract_so/ PRACT_SO

# we list the contents of our home directory so we can see that the name has change
ls

# we go to the WORK directory
cd PRACT_SO/WORK/

# we list the directory so we can see what has happened to our previously created links
ls -l

# we change the name of the working file and  we remove the not working one.
# we can execute 2 independent commands in the same line using " ; "
mv LexA_all.fst_2 LexA_all.fst ; rm LexA_all.fst_1

# we go to our home directory
cd

##############
# Exercise 2 #
##############


# NOTE: everything inside two " % " must not be typed literally, its meaning must be typed.

# we go to the previously created WORK directory
cd PRACT_SO/WORK/

# we try to execute clustal2_sleep, a multiple sequence alignment program
#clustalw2_sleep -ALIGN -OUTFILE=Lex_A.all.aln -INFILE=LexA_all.fst
# clustalw2_sleep did not execute because our current directory is not in our path

#we check our path
pwd

#we check which directories are in PATH
echo $PATH

# we can execute clustalw2_sleep using an absolute PATH
/home/$USER/PRACT_SO/WORK/clustalw2 -ALIGN -OUTFILE=Lex_A.all.aln -INFILE=LexA_all.fst
# but we execute it using a relative PATH which is easier
#./clustalw2 -ALIGN -OUTFILE=Lex_A.all.aln -INFILE=LexA_all.fst
# we press "ENTER" and observe how the terminal seems dead
# we press "Ctrl z" and observe how we recover the terminal but we see this mesage "[1]+  Stopped"
# this means that our program has paused execution

# we execute "ps" in order to see which process are running in our shell an their "pid"
# pid = Process Identifier
ps -f

# we send our process to the background so the execution continues and we still can use the terminal
#bg

# we try to see how many resources our program is using in real time
# to refresh "top" screen use space bar
#top -p %clustal2_sleep pid%

##########################################################
#previous line can not be scripted because it required   #
#user intervention, could be scripted in a different way #
##########################################################


# we execute the process in the background adding the "&" at the end
/usr/local/clustalw2/clustalw2 -ALIGN -OUTFILE=Lex_A.all.aln -INFILE=LexA_all.fst &

# we send it to the foreground
fg


# we execute the process in the background again
/usr/local/clustalw2/clustalw2 -ALIGN -OUTFILE=Lex_A.all.aln -INFILE=LexA_all.fst &

# we execute ps to see its pid (observe that the pid is different)
ps -f





##############
# Exercise 4#
##############


# we go to the home directory
cd
# we go to the SEQS directory
cd PRACT_SO/SEQS/

# we remove LexA_all.fst
rm LexA_all.fst

# we create it again from the individual sequence files
# we send the contents of all the files that have ".fst" at the end of their names to the stdout and we redirect the stdout to a file
cat *.fst >LexA_all.fsta

# we take a look to the files
less LexA_all.fsta
less Eco.fst
less Det.fst

# now we are going to execute clustalw2_sleep in interactive mode
# clustalw2_sleep
# we choose option 1 to enter the sequences from disk
# we type the file with our sequences:
# LexA_all.fsta
#we choose option
# 2
# we do the multiple alignment choosing option
# 1
#we accept default alignment output file pressing ENTER

#we accept default tree output file pressing ENTER

# we press ENTER again to see the whole alignment

# ENTER again to continue

# exit the menu we type
# X
# and to exit the program
# X


#we take a look to the output alignment
less LexA_all.aln

#we remove all output files
rm LexA_all.dnd LexA_all.aln

# now we take a look to this file /home/$USER/OSCAR_OS/clustw_stdin.txt
less /home/$USER/OSCAR_OS/clustw_stdin.txt
#Does its contents rings a bell to you?

# we execute clustalw2_sleep redirecting stdin to this file
/usr/local/clustalw2/clustalw2 </home/$USER/OSCAR_OS/clustw_stdin.txt

#we execute ls -ltr to see all files sorted by creation date
ls -ltr

#which new files have been created? what is inside them? What Just Happened?

#what is the output of this command
grep Bsu LexA_all.aln

#and this one:
ps -ef|grep $USER
#and this one:
ps -ef|grep $USER|less



##############
# Exercise 6 #
##############


cd
cd PRACT_SO/
mkdir PROGRAMS
cd PROGRAMS/
wget "ftp://ftp.ebi.ac.uk/pub/software/clustalw2/2.0.10/clustalw-2.0.10-src.tar.gz"
tar zxvf clustalw-2.0.10-src.tar.gz
ls clustalw-2.0.10


# Just for command line "frikis": what this line does if you execute it? :
# grep ">" LexA_all.fsta |cut -d ">" -f 2|xargs -i bash -c "echo \>{};grep {} LexA_all.aln"|awk '{if (NF==2) print $2;if(NF==1) print $1}' > LexA_all.aln.fsta
